/*****************************************************************************
 * vlc_objects.h: vlc_object_t definition.
 *****************************************************************************
 * Copyright (C) 2002 VideoLAN
 * $Id: main.h,v 1.35 2002/04/27 22:11:22 gbazin Exp $
 *
 * Authors: Samuel Hocevar <sam@zoy.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

/* Object types */
#define VLC_OBJECT_ROOT          1
#define VLC_OBJECT_MODULE        2
#define VLC_OBJECT_INTF          3
#define VLC_OBJECT_PLAYLIST      4
#define VLC_OBJECT_INPUT         5
#define VLC_OBJECT_DECODER       6
#define VLC_OBJECT_VOUT          7
#define VLC_OBJECT_AOUT          8
#define VLC_OBJECT_VDEC          9 /* FIXME: this should disappear */

/* Object search mode */
#define FIND_PARENT         0x0001
#define FIND_CHILD          0x0002
#define FIND_ANYWHERE       0x0003

#define FIND_STRICT         0x0010

/*****************************************************************************
 * Prototypes
 *****************************************************************************/
VLC_EXPORT( void *, __vlc_object_create, ( vlc_object_t *, int ) );
VLC_EXPORT( vlc_object_t *, __vlc_object_find, ( vlc_object_t *, int, int ) );
VLC_EXPORT( void, __vlc_object_release, ( vlc_object_t * ) );
VLC_EXPORT( void, __vlc_object_unlink, ( vlc_object_t *, vlc_object_t * ) );
VLC_EXPORT( void, __vlc_object_unlink_all, ( vlc_object_t * ) );
VLC_EXPORT( void, __vlc_object_acquire, ( vlc_object_t * ) );
VLC_EXPORT( void, __vlc_object_setparent, ( vlc_object_t *, vlc_object_t * ) );
VLC_EXPORT( void, __vlc_object_setchild, ( vlc_object_t *, vlc_object_t * ) );

#define vlc_object_create(a,b) \
    __vlc_object_create( CAST_TO_VLC_OBJECT(a), b )

#define vlc_object_find(a,b,c) \
    __vlc_object_find( CAST_TO_VLC_OBJECT(a),b,c)

#define vlc_object_find_root(a,b) \
    ((vlc_t *)vlc_object_find(a,VLC_OBJECT_ROOT,b))
#define vlc_object_find_module(a,b) \
    ((module_t *)vlc_object_find(a,VLC_OBJECT_MODULE,b))
#define vlc_object_find_intf(a,b) \
    ((intf_thread_t *)vlc_object_find(a,VLC_OBJECT_INTF,b))
#define vlc_object_find_playlist(a,b) \
    ((playlist_t *)vlc_object_find(a,VLC_OBJECT_PLAYLIST,b))
#define vlc_object_find_input(a,b) \
    ((input_thread_t *)vlc_object_find(a,VLC_OBJECT_INPUT,b))
#define vlc_object_find_decoder(a,b) \
    ((decoder_fifo_t *)vlc_object_find(a,VLC_OBJECT_DECODER,b))
#define vlc_object_find_aout(a,b) \
    ((aout_thread_t *)vlc_object_find(a,VLC_OBJECT_AOUT,b))
#define vlc_object_find_vout(a,b) \
    ((vout_thread_t *)vlc_object_find(a,VLC_OBJECT_VOUT,b))

#define vlc_object_acquire(a) \
    __vlc_object_acquire( CAST_TO_VLC_OBJECT(a) )

#define vlc_object_release(a) \
    __vlc_object_release( CAST_TO_VLC_OBJECT(a) )

#define vlc_object_unlink(a,b) \
    __vlc_object_unlink( CAST_TO_VLC_OBJECT(a), CAST_TO_VLC_OBJECT(b) )

#define vlc_object_unlink_all(a) \
    __vlc_object_unlink_all( CAST_TO_VLC_OBJECT(a) )

#define vlc_object_setparent(a,b) \
    __vlc_object_setparent( CAST_TO_VLC_OBJECT(a), CAST_TO_VLC_OBJECT(b) )

#define vlc_object_setchild(a,b) \
    __vlc_object_setchild( CAST_TO_VLC_OBJECT(a), CAST_TO_VLC_OBJECT(b) )

