/*****************************************************************************
 * vlc.c: the vlc player
 *****************************************************************************
 * Copyright (C) 1998-2001 VideoLAN
 * $Id: main.c,v 1.187 2002/04/24 00:36:24 sam Exp $
 *
 * Authors: Vincent Seguin <seguin@via.ecp.fr>
 *          Samuel Hocevar <sam@zoy.org>
 *          Gildas Bazin <gbazin@netcourrier.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/
#include <signal.h>                               /* SIGHUP, SIGINT, SIGKILL */
#include <stdio.h>                                              /* fprintf() */
#include <stdlib.h>                                  /* putenv(), strtol(),  */

#include <vlc/vlc.h>

//#define DOUBLE

/*****************************************************************************
 * main: parse command line, start interface and spawn threads
 *****************************************************************************/
int main(int i_argc, char *ppsz_argv[], char *ppsz_env[])
{
    vlc_t *p_vlc;
#ifdef DOUBLE
    vlc_t *p_vlc2;
#endif
    int i_ret;

#ifdef SYS_LINUX
#   ifdef DEBUG
    /* Activate malloc checking routines to detect heap corruptions. */
    putenv( "MALLOC_CHECK_=2" );

    /* Disable the ugly Gnome crash dialog so that we properly segfault */
    putenv( "GNOME_DISABLE_CRASH_DIALOG=1" );
#   endif
#endif

    /* Create the vlc structure */
    p_vlc = vlc_create();
    if( p_vlc == NULL )
    {
        return -1;
    }

    /* Initialize vlc */
    i_ret = vlc_init( p_vlc, i_argc, ppsz_argv );
    if( i_ret != 0 )
    {
        vlc_destroy( p_vlc );
        return i_ret;
    }

#ifdef DOUBLE
    p_vlc2 = vlc_create();
    vlc_init( p_vlc2, i_argc, ppsz_argv );
    vlc_add_intf( p_vlc2, 0 );
#endif

#ifdef UGLY_TEST
    vlc_add( p_vlc, "/home/sam/videolan/streams/mpeg/axe.mpeg" );
#endif

    /* Run vlc, in non-blocking mode */
    i_ret = vlc_run( p_vlc, 0 );

    /* Add an interface */
    i_ret = vlc_add_intf( p_vlc, 1 );
    if( i_ret != 0 )
    {
        vlc_end( p_vlc );
        vlc_destroy( p_vlc );
        return i_ret;
    }

#ifdef DOUBLE
    vlc_stop( p_vlc2 );
    vlc_end( p_vlc2 );
    vlc_destroy( p_vlc2 );
#endif

    /* Finish the interface */
    vlc_stop( p_vlc );

    /* Finish all threads */
    vlc_end( p_vlc );

    /* Destroy the vlc structure */
    vlc_destroy( p_vlc );

    return 0;
}

